pub struct RuntimeMetrics { /* private fields */ }Implementations
Sourceimpl RuntimeMetrics
impl RuntimeMetrics
Sourcepub fn new(core_count: usize, raft_group_count: usize) -> Self
pub fn new(core_count: usize, raft_group_count: usize) -> Self
Create an empty metric set sized for a runtime topology.
Sourcepub fn group_engine_metrics(&self) -> GroupEngineMetrics
pub fn group_engine_metrics(&self) -> GroupEngineMetrics
Return the metric handle passed to one group engine.
Sourcepub fn record_raft_snapshot_pressure(&self, groups: u64)
pub fn record_raft_snapshot_pressure(&self, groups: u64)
Records one aggregate Raft-log pressure snapshot pass.
Sourceimpl RuntimeMetrics
impl RuntimeMetrics
pub fn snapshot(&self) -> RuntimeMetricsSnapshot