ColdChunkRef

Type Alias ColdChunkRef 

pub type ColdChunkRef = ColdChunkRefV1;

Aliased Type

pub struct ColdChunkRef {
    pub start_offset: u64,
    pub end_offset: u64,
    pub s3_path: String,
    pub object_size: u64,
    pub object_offset: u64,
    pub shared_object: bool,
    pub payload_digest: String,
}

Fields

start_offset: u64end_offset: u64s3_path: Stringobject_size: u64object_offset: u64

Byte offset of this stream slice inside the physical object.

shared_object: bool

Shared objects may contain slices from more than one stream.

payload_digest: String

BLAKE3 digest of this logical slice. Empty on legacy references.