pub struct ColdGcEntry {
pub seq: u64,
pub target: ColdGcTarget,
}Expand description
One unit of deferred cold-storage reclamation. Enqueued deterministically in the state machine when a stream’s cold objects become unreferenced, drained asynchronously by the leader’s background GC worker.
Fields
seq: u64target: ColdGcTargetTrait Implementations
Sourceimpl Clone for ColdGcEntry
impl Clone for ColdGcEntry
Sourcefn clone(&self) -> ColdGcEntry
fn clone(&self) -> ColdGcEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColdGcEntry
impl Debug for ColdGcEntry
Sourceimpl<'de> Deserialize<'de> for ColdGcEntry
impl<'de> Deserialize<'de> for ColdGcEntry
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ColdGcEntry, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ColdGcEntry, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ColdGcEntry
Sourceimpl PartialEq for ColdGcEntry
impl PartialEq for ColdGcEntry
Sourceimpl Serialize for ColdGcEntry
impl Serialize for ColdGcEntry
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ColdGcEntry